from setuptools import setup, find_packages

setup(
    name="sparc_me",
    version="0.0.1",
    author="Thiranja Prasad Babarenda Gamage, Chinchien Lin, Thiranja Prasad Babarenda Gamage, Savindi Wijenayaka, Michael Hoffman, Linkun Gao, Haribalan Kumar",
    email="psam012@aucklanduni.ac.nz, clin864@aucklanduni.ac.nz",
    license="Apache-2.0",
    packages=["sparc_me"]
)
